@@ -11,6 +11,7 @@ from fab_deploy.system import prepare_server
 from fab_deploy.apache import apache_setup, apache_install, touch
 from fab_deploy.nginx import nginx_setup, nginx_install
 from fab_deploy.virtualenv import virtualenv_create
+from fab_deploy import vcs
 
 def full_deploy():
     """ Prepares server and deploys the project. """
@@ -21,9 +22,8 @@ def deploy_project():
     """ Deploys project on prepared server. """
     virtualenv_create()
     make_clone()
-    make_hgrc()
 
-    pip_update('all', restart=False)
+    pip_install('all', restart=False)
 
     setup_web_server()
     update_django_config()
@@ -37,16 +37,13 @@ def make_clone():
         with settings(warn_only=True):
             run('mkdir %s' % env.conf['INSTANCE_NAME'])
             with cd(env.conf['INSTANCE_NAME']):
-                run('hg init')
-    local('hg push ssh://%s/src/%s/' % (env.hosts[0], env.conf['INSTANCE_NAME']))
+                vcs.init()
+    vcs.push()
     with cd('src'):
         with cd(env.conf['INSTANCE_NAME']):
-            run('hg up -C %s' % env.conf['HG_BRANCH'])
+            vcs.up()
     update_django_config(restart=False)
-
-def make_hgrc():
-    """ Updates hgrc file. """
-    upload_config_template('hgrc', env.conf['SRC_DIR'] + '/.hg/hgrc')
+    vcs.configure()
 
 def update_django_config(restart=True):
     """ Updates :file:`config.py` on server (using :file:`config.server.py`) """
@@ -55,11 +52,11 @@ def update_django_config(restart=True):
         touch()
 
 def up(branch=None):
-    """ Runs ``hg up`` on server and reloads mod_wsgi process. """
+    """ Runs vcs ``up`` or ``checkout`` command on server and reloads
+    mod_wsgi process. """
     delete_pyc()
-    branch = branch or env.conf['HG_BRANCH']
     with cd('src/'+ env.conf['INSTANCE_NAME']):
-        run('hg up -C %s' % branch)
+        vcs.up(branch)
     compress()
     touch()
 
@@ -72,7 +69,7 @@ def setup_web_server():
     nginx_setup()
 
 def push(*args):
-    ''' Run it instead of hg push.
+    ''' Run it instead of your VCS push command.
 
     Arguments:
 
@@ -89,11 +86,10 @@ def push(*args):
             print 'Valid arguments are: %s' % allowed_args
             return
 
-    repo = 'ssh://%s/src/%s/' % (env.hosts[0], env.conf['INSTANCE_NAME'])
-    local('hg push %s' % repo)
+    vcs.push()
     delete_pyc()
     with cd('src/'+env.conf['INSTANCE_NAME']):
-        run('hg up')
+        vcs.up()
 
     if 'pip_update' in args:
         pip_update(restart=False)
@@ -123,3 +119,5 @@ def undeploy():
 
     wipe_web()
     run('rm -rf %s' % env.conf['SRC_DIR'])
+    for folder in ['bin', 'include', 'lib', 'src']:
+        run('rm -rf %s' % env.conf['ENV_DIR'] + '/' + folder)
